from jhomeassistant.types.units.base import BaseUnit


class SpeedUnit(BaseUnit):
    FOOT_PER_SECOND = "ft/s"
    KILOMETER_PER_HOUR = "km/h"
    KNOT = "kn"
    METER_PER_SECOND = "m/s"
    MILE_PER_HOUR = "mph"
    INCH_PER_DAY = "in/d"
    INCH_PER_HOUR = "in/h"
    INCH_PER_SECOND = "in/s"
    MILLIMETER_PER_DAY = "mm/d"
    MILLIMETER_PER_SECOND = "mm/s"
