from .number_device_class import NumberDeviceClass
from .sensor_device_class import SensorDeviceClass
from .binary_sensor_device_class import BinarySensorDeviceClass
from .button_device_class import ButtonDeviceClass
from .cover_device_class import CoverDeviceClass
from .event_device_class import EventDeviceClass
from .valve_device_class import ValveDeviceClass
from .switch_device_class import SwitchDeviceClass
from .update_device_class import UpdateDeviceClass
from .humidifier_device_class import HumidifierDeviceClass
from .media_player_device_class import MediaPlayerDeviceClass
