from jhomeassistant.types.units.base import BaseUnit


class EnergyUnit(BaseUnit):
    JOULE = "J"
    KILOJOULE = "kJ"
    MEGAJOULE = "MJ"
    GIGAJOULE = "GJ"
    MILLIWATT_HOUR = "mWh"
    WATT_HOUR = "Wh"
    KILOWATT_HOUR = "kWh"
    MEGAWATT_HOUR = "MWh"
    GIGAWATT_HOUR = "GWh"
    TERAWATT_HOUR = "TWh"
    CALORIE = "cal"
    KILOCALORIE = "kcal"
    MEGACALORIE = "Mcal"
    GIGACALORIE = "Gcal"
