from jhomeassistant.types.units.base import BaseUnit


class DataSizeUnit(BaseUnit):
    BIT = "bit"
    KILOBIT = "kbit"
    MEGABIT = "Mbit"
    GIGABIT = "Gbit"
    BYTE = "B"
    KILOBYTE = "kB"
    MEGABYTE = "MB"
    GIGABYTE = "GB"
    TERABYTE = "TB"
    PETABYTE = "PB"
    EXABYTE = "EB"
    ZETTABYTE = "ZB"
    YOTTABYTE = "YB"
    KIBIBYTE = "KiB"
    MEBIBYTE = "MiB"
    GIBIBYTE = "GiB"
    TEBIBYTE = "TiB"
    PEBIBYTE = "PiB"
    EXBIBYTE = "EiB"
    ZEBIBYTE = "ZiB"
    YOBIBYTE = "YiB"
