from jhomeassistant.types.units.base import BaseUnit


class ConductivityUnit(BaseUnit):
    SIEMENS_PER_CENTIMETER = "S/cm"
    MILLISIEMENS_PER_CENTIMETER = "mS/cm"
    MICROSIEMENS_PER_CENTIMETER = "µS/cm"
