from jhomeassistant.types.units.base import BaseUnit


class EnergyDistanceUnit(BaseUnit):
    KILOWATT_HOUR_PER_ONE_HUNDRED_KILOMETERS = "kWh/100km"
    WATT_HOUR_PER_KILOMETER = "Wh/km"
    MILE_PER_KILOWATT_HOUR = "mi/kWh"
    KILOMETER_PER_KILOWATT_HOUR = "km/kWh"
