from jhomeassistant.types.device_classes.base_device_class import BaseDeviceClass


class CoverDeviceClass(BaseDeviceClass):
    NONE = None
    AWNING = "awning"
    BLIND = "blind"
    CURTAIN = "curtain"
    DAMPER = "damper"
    DOOR = "door"
    GARAGE = "garage"
    GATE = "gate"
    SHADE = "shade"
    SHUTTER = "shutter"
    WINDOW = "window"
