from jhomeassistant.types.units.base import BaseUnit


class PressureSensorUnit(BaseUnit):
    CENTIBAR = "cbar"
    BAR = "bar"
    MILLIBAR = "mbar"
    PASCAL = "Pa"
    HECTOPASCAL = "hPa"
    KILOPASCAL = "kPa"
    INCH_OF_MERCURY = "inHg"
    MILLIMETER_OF_MERCURY = "mmHg"
    POUND_PER_SQUARE_INCH = "psi"
    INCH_OF_WATER = "inH₂O"
    MILLIPASCAL = "mPa"


class PressureNumberUnit(BaseUnit):
    CENTIBAR = "cbar"
    BAR = "bar"
    MILLIBAR = "mbar"
    PASCAL = "Pa"
    HECTOPASCAL = "hPa"
    KILOPASCAL = "kPa"
    INCH_OF_MERCURY = "inHg"
    MILLIMETER_OF_MERCURY = "mmHg"
    POUND_PER_SQUARE_INCH = "psi"
    INCH_OF_WATER = "inH₂O"
