from jhomeassistant.types.units.base import BaseUnit


class VolumeStorageUnit(BaseUnit):
    LITRE = "L"
    MILLILITRE = "mL"
    GALLON = "gal"
    CUBIC_FOOT = "ft³"
    CUBIC_METER = "m³"
    CENTUM_CUBIC_FEET = "CCF"
    THOUSAND_CUBIC_FEET = "MCF"
    FLUID_OUNCE = "fl. oz."
