from jhomeassistant.types.units.base import BaseUnit


class WeightUnit(BaseUnit):
    KILOGRAM = "kg"
    GRAM = "g"
    MILLIGRAM = "mg"
    MICROGRAM = "µg"
    OUNCE = "oz"
    POUND = "lb"
    STONE = "st"
