from jhomeassistant.types.units.base import BaseUnit


class AreaUnit(BaseUnit):
    SQUARE_METER = "m²"
    SQUARE_CENTIMETER = "cm²"
    SQUARE_KILOMETER = "km²"
    SQUARE_MILLIMETER = "mm²"
    SQUARE_INCH = "in²"
    SQUARE_FOOT = "ft²"
    SQUARE_YARD = "yd²"
    SQUARE_MILE = "mi²"
    ACRE = "ac"
    HECTARE = "ha"
