from jhomeassistant.types.units.base import BaseUnit


class DistanceUnit(BaseUnit):
    KILOMETER = "km"
    METER = "m"
    CENTIMETER = "cm"
    MILLIMETER = "mm"
    MILE = "mi"
    NAUTICAL_MILE = "nmi"
    YARD = "yd"
    INCH = "in"
