from jhomeassistant.types.units.base import BaseUnit


class PrecipitationIntensityUnit(BaseUnit):
    INCH_PER_DAY = "in/d"
    INCH_PER_HOUR = "in/h"
    MILLIMETER_PER_DAY = "mm/d"
    MILLIMETER_PER_HOUR = "mm/h"
