from jhomeassistant.types.units.base import BaseUnit


class WindSpeedUnit(BaseUnit):
    FOOT_PER_SECOND = "ft/s"
    KILOMETER_PER_HOUR = "km/h"
    KNOT = "kn"
    METER_PER_SECOND = "m/s"
    MILE_PER_HOUR = "mph"
    BEAUFORT = "Beaufort"
