from jhomeassistant.types.units.base import BaseUnit


class VolumeFlowRateSensorUnit(BaseUnit):
    CUBIC_METER_PER_HOUR = "m³/h"
    CUBIC_METER_PER_MINUTE = "m³/min"
    CUBIC_METER_PER_SECOND = "m³/s"
    CUBIC_FOOT_PER_MINUTE = "ft³/min"
    LITER_PER_HOUR = "L/h"
    LITER_PER_MINUTE = "L/min"
    LITER_PER_SECOND = "L/s"
    GALLON_PER_MINUTE = "gal/min"
    MILLILITER_PER_SECOND = "mL/s"
    GALLON_PER_HOUR = "gal/h"


class VolumeFlowRateNumberUnit(BaseUnit):
    CUBIC_METER_PER_HOUR = "m³/h"
    CUBIC_METER_PER_MINUTE = "m³/min"
    CUBIC_METER_PER_SECOND = "m³/s"
    CUBIC_FOOT_PER_MINUTE = "ft³/min"
    LITER_PER_HOUR = "L/h"
    LITER_PER_MINUTE = "L/min"
    LITER_PER_SECOND = "L/s"
    GALLON_PER_MINUTE = "gal/min"
    MILLILITER_PER_SECOND = "mL/s"
