from jhomeassistant.types.units.base import BaseUnit


class DataRateUnit(BaseUnit):
    BIT_PER_SECOND = "bit/s"
    KILOBIT_PER_SECOND = "kbit/s"
    MEGABIT_PER_SECOND = "Mbit/s"
    GIGABIT_PER_SECOND = "Gbit/s"
    BYTE_PER_SECOND = "B/s"
    KILOBYTE_PER_SECOND = "kB/s"
    MEGABYTE_PER_SECOND = "MB/s"
    GIGABYTE_PER_SECOND = "GB/s"
    KIBIBYTE_PER_SECOND = "KiB/s"
    MEBIBYTE_PER_SECOND = "MiB/s"
    GIBIBYTE_PER_SECOND = "GiB/s"
