from .validation import (validate_discovery_prefix, validate_entity_specification, validate_icon,
                         validate_topic, validate_non_empty_string)
from .device_data_detection import collect_ha_device_facts
from .naming import get_default_entity_id, build_identifier
